.. include:: front_page.md
   :parser: myst_parser.sphinx_

Table of contents
==================

.. toctree::
   :maxdepth: 3

   installation.md

.. toctree::
   :maxdepth: 3
   
   how_to_run.md

.. toctree::
   :maxdepth: 3
   
   inputs_outputs.md

.. toctree::
   :maxdepth: 3
   
   tips.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
